@@ -3,8 +3,10 @@ import cleo
 from pyadr import __version__
 from pyadr.cli.commands import (
     AcceptCommand,
+    CheckAdrRepoCommand,
     ConfigCommand,
     GenerateTocCommand,
+    HelperCommand,
     InitCommand,
     NewCommand,
     ProposeCommand,
@@ -26,3 +28,5 @@ class App(cleo.Application):
         self.add(AcceptCommand())
         self.add(RejectCommand())
         self.add(GenerateTocCommand())
+        self.add(CheckAdrRepoCommand())
+        self.add(HelperCommand())
